@@ -1796,7 +1796,9 @@ class TrManager:
         # document template.
         tplDic = {}
 
-        s = 'Do not edit this file. It was generated by the %s script. * Instead edit %s and %s' % (self.script_name, self.languageTplFileName, self.maintainersFileName)
+        s = ('Do not edit this file. It was generated by the %s script.\n' +\
+             ' * Edit the %s and %s files instead.') % (
+             self.script_name, self.languageTplFileName, self.maintainersFileName)
         tplDic['editnote'] = s
 
         tplDic['doxVersion'] = self.doxVersion
@@ -1812,6 +1814,7 @@ class TrManager:
         # Define templates for HTML table parts of the documentation.
         htmlTableTpl = '''\
             \\htmlonly
+			</p>
             <table align="center" cellspacing="0" cellpadding="0" border="0">
             <tr bgcolor="#000000">
             <td>
@@ -1830,6 +1833,7 @@ class TrManager:
             </td>
             </tr>
             </table>
+			<p>
             \\endhtmlonly
             '''
         htmlTableTpl = textwrap.dedent(htmlTableTpl)
@@ -1987,17 +1991,14 @@ if __name__ == '__main__':
 
     # The Python 2.6+ or 3.3+ is required.
     major, minor, patch = (int(e) for e in platform.python_version_tuple())
-    print(major, minor, patch)
     if (major == 2 and minor < 6) or (major == 3 and minor < 0):
         print('Python 2.6+ or Python 3.0+ are required for the script')
         sys.exit(1)
 
-    # The translator manager builds the transl objects, parses the related
+    # The translator manager builds the Transl objects, parses the related
     # sources, and keeps them in memory.
     trMan = TrManager()
 
-    # Generate the language.doc.
+    # Process the Transl objects and generate the output files.
     trMan.generateLanguageDoc()
-
-    # Generate the translator report.
     trMan.generateTranslatorReport()
