@@ -52,7 +52,7 @@
 #include <dos.h>
 #elif defined(_OS_OS2_)
 #include <os2.h>
-#elif defined(_OS_UNIX_)
+#elif defined(_OS_UNIX_) || defined(_OS_MAC_)
 #include <sys/time.h>
 #include <unistd.h>
 #undef	gettimeofday
@@ -893,7 +893,7 @@ bool QTime::currentTime( QTime *ct )
 	     t.second*1000 + t.hsecond*10;
     return (t.hour== 0 && t.minute == 0);
 
-#elif defined(_OS_UNIX_)
+#elif defined(_OS_UNIX_) || defined(_OS_MAC_)
 
     struct timeval tv;
     gettimeofday( &tv, 0 );
