@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -30,37 +30,39 @@ struct Argument
   /*! Construct a new argument. */
   Argument() {}
   /*! Copy an argument (does a deep copy of all strings). */
-  Argument(const Argument &a) 
-  { 
-    attrib=a.attrib.copy();
-    type=a.type.copy(); 
-    name=a.name.copy(); 
-    defval=a.defval.copy(); 
-    docs=a.docs.copy();
-    array=a.array.copy();
+  Argument(const Argument &a)
+  {
+    attrib=a.attrib;
+    type=a.type;
+    name=a.name;
+    array=a.array;
+    defval=a.defval;
+    docs=a.docs;
+    typeConstraint=a.typeConstraint;
   }
   /*! Assignment of an argument (does a deep copy of all strings). */
   Argument &operator=(const Argument &a)
   {
     if (this!=&a)
     {
-      attrib=a.attrib.copy();
-      type=a.type.copy(); 
-      name=a.name.copy(); 
-      defval=a.defval.copy(); 
-      docs=a.docs.copy();
-      array=a.array.copy();
+      attrib=a.attrib;
+      type=a.type;
+      name=a.name;
+      array=a.array;
+      defval=a.defval;
+      docs=a.docs;
+      typeConstraint=a.typeConstraint;
     }
     return *this;
   }
   /*! return TRUE if this argument is documentation and the argument has a
    *  non empty name.
    */
-  bool hasDocumentation() const 
-  { 
-    return !name.isEmpty() && !docs.isEmpty(); 
+  bool hasDocumentation() const
+  {
+    return !name.isEmpty() && !docs.isEmpty();
   }
-  
+
   QCString attrib;   /*!< Argument's attribute (IDL only) */
   QCString type;     /*!< Argument's type */
   QCString canType;  /*!< Cached value of canonical type (after type resolution). Empty initially. */
@@ -68,6 +70,7 @@ struct Argument
   QCString array;    /*!< Argument's array specifier (may be empty) */
   QCString defval;   /*!< Argument's default value (may be empty) */
   QCString docs;     /*!< Argument's documentation (may be empty) */
+  QCString typeConstraint;  /*!< Used for Java generics: \<T extends C\> */
 };
 
 /*! \brief This class represents an function or template argument list. 
@@ -83,7 +86,8 @@ class ArgumentList : public QList<Argument>
     ArgumentList() : QList<Argument>(), 
                      constSpecifier(FALSE),
                      volatileSpecifier(FALSE),
-                     pureSpecifier(FALSE)
+                     pureSpecifier(FALSE),
+                     isDeleted(FALSE)
                      { setAutoDelete(TRUE); }
     /*! Destroys the argument list */
    ~ArgumentList() {}
@@ -99,7 +103,8 @@ class ArgumentList : public QList<Argument>
     bool pureSpecifier;
     /*! C++11 style Trailing return type? */
     QCString trailingReturnType;
-    /*! C++11 defaulted method */
+    /*! method with =delete */
+    bool isDeleted;
 
     static ArgumentList *unmarshal(StorageIntf *s);
     static void marshal(StorageIntf *s,ArgumentList *argList);
