@@ -1,13 +1,13 @@
 /******************************************************************************
  *
- * 
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ *
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby 
- * granted. No representations are made about the suitability of this software 
+ * documentation under the terms of the GNU General Public License is hereby
+ * granted. No representations are made about the suitability of this software
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -71,7 +71,7 @@ typedef QListIterator<QCString>    StringListIterator;
 
 class StringDict : public QDict<QCString>
 {
-  public: 
+  public:
     StringDict(uint size=17) : QDict<QCString>(size) {}
     virtual ~StringDict() {}
 };
@@ -79,7 +79,7 @@ class StringDict : public QDict<QCString>
 struct LookupInfo
 {
   LookupInfo() : classDef(0), typeDef(0) {}
-  LookupInfo(ClassDef *cd,MemberDef *td,QCString ts,QCString rt) 
+  LookupInfo(ClassDef *cd,MemberDef *td,QCString ts,QCString rt)
     : classDef(cd), typeDef(td), templSpec(ts),resolvedType(rt) {}
   ClassDef  *classDef;
   MemberDef *typeDef;
@@ -114,7 +114,6 @@ class Doxygen
     static QStrList                  tagfileList;
     static MemberNameSDict          *memberNameSDict;
     static MemberNameSDict          *functionNameSDict;
-    static FTextStream               tagFile;
     static SectionDict              *sectionDict;
     static StringDict                namespaceAliasDict;
     static GroupSDict               *groupSDict;
@@ -122,8 +121,8 @@ class Doxygen
     static FormulaList              *formulaList;
     static FormulaDict              *formulaDict;
     static FormulaDict              *formulaNameDict;
-    static StringDict                tagDestinationDict; 
-    static StringDict                aliasDict; 
+    static StringDict                tagDestinationDict;
+    static StringDict                aliasDict;
     static QIntDict<MemberGroupInfo> memGrpInfoDict;
     static QDict<void>               expandAsDefinedDict;
     static NamespaceDef             *globalScope;
