@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -281,6 +281,7 @@ HtmlHelp::HtmlHelp() : indexFileDict(1009)
 HtmlHelp::~HtmlHelp()
 {
   if (m_fromUtf8!=(void *)(-1))   portable_iconv_close(m_fromUtf8);
+  delete index;
 }
 #if 0
 /*! return a reference to the one and only instance of this class. 
@@ -598,8 +599,8 @@ QCString HtmlHelp::recode(const QCString &s)
   QCString output(oSize);
   size_t iLeft     = iSize;
   size_t oLeft     = oSize;
-  char *iPtr       = s.data();
-  char *oPtr       = output.data();
+  char *iPtr       = s.rawData();
+  char *oPtr       = output.rawData();
   if (!portable_iconv(m_fromUtf8,&iPtr,&iLeft,&oPtr,&oLeft))
   {
     oSize -= (int)oLeft;
