@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,36 +36,216 @@
 #include "classlist.h"
 #include "namespacedef.h"
 #include "filename.h"
+#include "resourcemgr.h"
 
-static const char doxygenLatexStyle[] =
-#include "doxygen.sty.h"
-;
+//-------------------------------
 
-//static QCString filterTitle(const char *s)
-//{
-//  QCString tmp=s,result;
-//  uint i;for (i=0;i<tmp.length();i++)
-//  {
-//    char c=tmp.at(i);
-//    switch(c)
-//    {
-//      case '#': result+="\\#";  break;
-//      case '"': result+="\\\""; break;
-//      case '%': result+="\\%";  break;
-//      case '[': result+="{";    break;
-//      case ']': result+="}";    break;
-//      default:  result+=c;      break;
-//    }
-//  }
-//  return result;  
-//}
+LatexCodeGenerator::LatexCodeGenerator(FTextStream &t,const QCString &relPath,const QCString &sourceFileName)
+  : m_relPath(relPath), m_sourceFileName(sourceFileName), m_col(0)
+{
+  m_prettyCode=Config_getBool("LATEX_SOURCE_CODE");
+  setTextStream(t);
+}
+
+LatexCodeGenerator::LatexCodeGenerator() : m_col(0), m_streamSet(FALSE)
+{
+  m_prettyCode=Config_getBool("LATEX_SOURCE_CODE");
+}
+
+void LatexCodeGenerator::setTextStream(FTextStream &t)
+{
+  m_streamSet = t.device()!=0;
+  m_t.setDevice(t.device());
+}
+
+void LatexCodeGenerator::setRelativePath(const QCString &path)
+{
+  m_relPath = path;
+}
+
+void LatexCodeGenerator::setSourceFileName(const QCString &name)
+{
+  m_sourceFileName = name;
+}
+
+void LatexCodeGenerator::codify(const char *str)
+{
+  if (str)
+  {
+    const char *p=str;
+    char c;
+    //char cs[5];
+    int spacesToNextTabStop;
+    static int tabSize = Config_getInt("TAB_SIZE");
+    const int maxLineLen = 108;
+    QCString result(4*maxLineLen+1); // worst case for 1 line of 4-byte chars
+    int i;
+    while ((c=*p))
+    {
+      switch(c)
+      {
+        case 0x0c: p++;  // remove ^L
+                   break;
+        case '\t': spacesToNextTabStop =
+                         tabSize - (m_col%tabSize);
+                   m_t << Doxygen::spaces.left(spacesToNextTabStop);
+                   m_col+=spacesToNextTabStop;
+                   p++;
+                   break;
+        case '\n': m_t << '\n'; m_col=0; p++;
+                   break;
+        default:
+                   i=0;
+
+#undef  COPYCHAR
+// helper macro to copy a single utf8 character, dealing with multibyte chars.
+#define COPYCHAR() do {                                           \
+                     result[i++]=c; p++;                          \
+                     if (c<0) /* multibyte utf-8 character */     \
+                     {                                            \
+                       /* 1xxx.xxxx: >=2 byte character */        \
+                       result[i++]=*p++;                          \
+                       if (((uchar)c&0xE0)==0xE0)                 \
+                       {                                          \
+                         /* 111x.xxxx: >=3 byte character */      \
+                         result[i++]=*p++;                        \
+                       }                                          \
+                       if (((uchar)c&0xF0)==0xF0)                 \
+                       {                                          \
+                         /* 1111.xxxx: 4 byte character */        \
+                         result[i++]=*p++;                        \
+                       }                                          \
+                     }                                            \
+                     m_col++;                                       \
+                   } while(0)
+
+                   // gather characters until we find whitespace or are at
+                   // the end of a line
+                   COPYCHAR();
+                   if (m_col>=maxLineLen) // force line break
+                   {
+                     m_t << "\n      ";
+                     m_col=0;
+                   }
+                   else // copy more characters
+                   {
+                     while (m_col<maxLineLen && (c=*p) &&
+                            c!=0x0c && c!='\t' && c!='\n' && c!=' '
+                           )
+                     {
+                       COPYCHAR();
+                     }
+                     if (m_col>=maxLineLen) // force line break
+                     {
+                       m_t << "\n      ";
+                       m_col=0;
+                     }
+                   }
+                   result[i]=0; // add terminator
+                   //if (m_prettyCode)
+                   //{
+                     filterLatexString(m_t,result,FALSE,TRUE);
+                   //}
+                   //else
+                   //{
+                   //  t << result;
+                   //}
+                   break;
+      }
+    }
+  }
+}
 
 
+void LatexCodeGenerator::writeCodeLink(const char *ref,const char *f,
+                                   const char *anchor,const char *name,
+                                   const char *)
+{
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
+  int l = qstrlen(name);
+  if (m_col+l>80)
+  {
+    m_t << "\n      ";
+    m_col=0;
+  }
+  if (!ref && usePDFLatex && pdfHyperlinks)
+  {
+    m_t << "\\hyperlink{";
+    if (f) m_t << stripPath(f);
+    if (f && anchor) m_t << "_"; 
+    if (anchor) m_t << anchor; 
+    m_t << "}{";
+    codify(name);
+    m_t << "}";
+  }
+  else
+  {
+    m_t << name;
+  }
+  m_col+=l;
+}
+
+void LatexCodeGenerator::writeLineNumber(const char *ref,const char *fileName,const char *anchor,int l)
+{
+  static bool usePDFLatex = Config_getBool("USE_PDFLATEX");
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  if (m_prettyCode)
+  {
+    QCString lineNumber;
+    lineNumber.sprintf("%05d",l);
+
+    if (fileName && !m_sourceFileName.isEmpty())
+    {
+      QCString lineAnchor;
+      lineAnchor.sprintf("_l%05d",l);
+      lineAnchor.prepend(m_sourceFileName);
+      //if (!m_prettyCode) return;
+      if (usePDFLatex && pdfHyperlinks)
+      {
+        m_t << "\\hypertarget{" << stripPath(lineAnchor) << "}{}";
+      }
+      writeCodeLink(ref,fileName,anchor,lineNumber,0);
+    }
+    else
+    {
+      codify(lineNumber);
+    }
+    m_t << " ";
+  }
+  else
+  {
+    m_t << l << " ";
+  }
+}
+
+
+void LatexCodeGenerator::startCodeLine(bool)
+{
+  m_col=0;
+}
+
+void LatexCodeGenerator::endCodeLine()
+{
+  codify("\n");
+}
+
+void LatexCodeGenerator::startFontClass(const char *name)
+{
+  m_t << "\\textcolor{" << name << "}{";
+}
+
+void LatexCodeGenerator::endFontClass()
+{
+  m_t << "}";
+}
+
+
+//-------------------------------
 
 LatexGenerator::LatexGenerator() : OutputGenerator()
 {
   dir=Config_getString("LATEX_OUTPUT");
-  col=0;
   //printf("LatexGenerator::LatexGenerator() insideTabbing=FALSE\n");
   insideTabbing=FALSE;
   firstDescItem=TRUE;
@@ -293,7 +473,29 @@ static void writeDefaultHeaderPart1(FTextStream &t)
        "\\usepackage{fixltx2e}\n" // for \textsubscript
        "\\usepackage{calc}\n"
        "\\usepackage{doxygen}\n"
-       "\\usepackage{graphicx}\n"
+       "\\usepackage[export]{adjustbox} % also loads graphicx\n";
+  QStrList extraLatexStyle = Config_getList("LATEX_EXTRA_STYLESHEET");
+  for (uint i=0; i<extraLatexStyle.count(); ++i)
+  {
+    QCString fileName(extraLatexStyle.at(i));
+    if (!fileName.isEmpty())
+    {
+      QFileInfo fi(fileName);
+      if (fi.exists())
+      {
+        if (checkExtension(fi.fileName().data(), latexStyleExtension))
+        {
+          // strip the extension, it will be added by the usepackage in the tex conversion process
+          t << "\\usepackage{" << stripExtensionGeneral(fi.fileName().data(), latexStyleExtension) << "}\n";
+        }
+        else
+        {
+          t << "\\usepackage{" << fi.fileName().utf8() << "}\n";
+        }
+      }
+    }
+  }
+  t << "\\usepackage{graphicx}\n"
        "\\usepackage[utf8]{inputenc}\n"
        "\\usepackage{makeidx}\n"
        "\\usepackage{multicol}\n"
@@ -316,7 +518,6 @@ static void writeDefaultHeaderPart1(FTextStream &t)
   // Define default fonts
   t << "% Font selection\n"
        "\\usepackage[T1]{fontenc}\n"
-       "\\usepackage{mathptmx}\n"
        "\\usepackage[scaled=.90]{helvet}\n"
        "\\usepackage{courier}\n"
        "\\usepackage{amssymb}\n"
@@ -334,13 +535,8 @@ static void writeDefaultHeaderPart1(FTextStream &t)
        "\n";
 
   // Define page & text layout
-  QCString paperName;
-  QCString &paperType=Config_getEnum("PAPER_TYPE");
+  QCString paperName=Config_getEnum("PAPER_TYPE");
   // "a4wide" package is obsolete (see bug 563698)
-  if (paperType=="a4wide")
-    paperName="a4";
-  else
-    paperName=paperType;
   t << "% Page & text layout\n"
        "\\usepackage{geometry}\n"
        "\\geometry{%\n"
@@ -357,7 +553,7 @@ static void writeDefaultHeaderPart1(FTextStream &t)
        "\\hbadness=750\n"
        "\\setlength{\\emergencystretch}{15pt}\n"
        "\\setlength{\\parindent}{0cm}\n"
-       "\\setlength{\\parskip}{0.2cm}\n";
+       "\\setlength{\\parskip}{3ex plus 2ex minus 2ex}\n";
   // Redefine paragraph/subparagraph environments, using sectsty fonts
   t << "\\makeatletter\n"
        "\\renewcommand{\\paragraph}{%\n"
@@ -375,11 +571,18 @@ static void writeDefaultHeaderPart1(FTextStream &t)
 
   // Headers & footers
   QGString genString;
+  QCString generatedBy;
+  static bool timeStamp = Config_getBool("LATEX_TIMESTAMP");
   FTextStream tg(&genString);
-  filterLatexString(tg,
-                    theTranslator->trGeneratedAt(dateToString(TRUE),
-                       Config_getString("PROJECT_NAME")),
-                    FALSE,FALSE,FALSE);
+  if (timeStamp)
+  {
+    generatedBy = theTranslator->trGeneratedAt(dateToString(TRUE), Config_getString("PROJECT_NAME"));
+  }
+  else
+  {
+    generatedBy = theTranslator->trGeneratedBy();
+  }
+  filterLatexString(tg, generatedBy, FALSE,FALSE,FALSE);
   t << "% Headers & footers\n"
        "\\usepackage{fancyhdr}\n"
        "\\pagestyle{fancyplain}\n"
@@ -423,7 +626,10 @@ static void writeDefaultHeaderPart1(FTextStream &t)
     const char *pkgName=extraPackages.first();
     while (pkgName)
     {
-      t << "\\usepackage{" << pkgName << "}\n";
+      if ((pkgName[0] == '[') || (pkgName[0] == '{'))
+        t << "\\usepackage" << pkgName << "\n";
+      else
+        t << "\\usepackage{" << pkgName << "}\n";
       pkgName=extraPackages.next();
     }
     t << "\n";
@@ -454,9 +660,12 @@ static void writeDefaultHeaderPart1(FTextStream &t)
        "\\newcommand{\\clearemptydoublepage}{%\n"
        "  \\newpage{\\pagestyle{empty}\\cleardoublepage}%\n"
        "}\n"
-       "\n"
        "\n";
 
+  // caption style definition
+  t << "\\usepackage{caption}\n"
+    << "\\captionsetup{labelsep=space,justification=centering,font={bf},singlelinecheck=off,skip=4pt,position=top}\n\n";
+
   // End of preamble, now comes the document contents
   t << "%===== C O N T E N T S =====\n"
        "\n"
@@ -473,7 +682,7 @@ static void writeDefaultHeaderPart1(FTextStream &t)
     // To avoid duplicate page anchors due to reuse of same numbers for
     // the index (be it as roman numbers)
     t << "\\hypersetup{pageanchor=false,\n"
-      << "             bookmarks=true,\n"
+    //  << "             bookmarks=true,\n" // commented out to prevent warning
       << "             bookmarksnumbered=true,\n"
       << "             pdfencoding=unicode\n"
       << "            }\n";
@@ -498,10 +707,11 @@ static void writeDefaultHeaderPart3(FTextStream &t)
 {
   // part 3
   // Finalize project number
-  t << " Doxygen " << versionString << "}\\\\\n"
-       "\\vspace*{0.5cm}\n"
-       "{\\small " << dateToString(TRUE) << "}\\\\\n"
-       "\\end{center}\n"
+  t << " Doxygen " << versionString << "}\\\\\n";
+  if (Config_getBool("LATEX_TIMESTAMP"))
+    t << "\\vspace*{0.5cm}\n"
+         "{\\small " << dateToString(TRUE) << "}\\\\\n";
+  t << "\\end{center}\n"
        "\\end{titlepage}\n";
   bool compactLatex = Config_getBool("COMPACT_LATEX");
   if (!compactLatex)
@@ -525,7 +735,7 @@ static void writeDefaultHeaderPart3(FTextStream &t)
 
 static void writeDefaultStyleSheet(FTextStream &t)
 {
-  t << doxygenLatexStyle;
+  t << ResourceMgr::instance().getAsString("doxygen.sty");
 }
 
 static void writeDefaultFooter(FTextStream &t)
@@ -537,14 +747,20 @@ static void writeDefaultFooter(FTextStream &t)
   Doxygen::citeDict->writeLatexBibliography(t);
 
   // Index
+  t << "% Index\n";
   QCString unit;
   if (Config_getBool("COMPACT_LATEX"))
+  {
     unit = "section";
+  }
   else
+  {
     unit = "chapter";
-  t << "% Index\n"
-       "\\newpage\n"
+    t << "\\backmatter\n";
+  }
+  t << "\\newpage\n"
        "\\phantomsection\n"
+       "\\clearemptydoublepage\n"
        "\\addcontentsline{toc}{" << unit << "}{" << theTranslator->trRTFGeneralIndex() << "}\n"
        "\\printindex\n"
        "\n"
@@ -583,15 +799,17 @@ void LatexGenerator::startFile(const char *name,const char *,const char *)
 #endif
   QCString fileName=name;
   relPath = relativePathToRoot(fileName);
-  sourceFileName = stripPath(fileName);
   if (fileName.right(4)!=".tex" && fileName.right(4)!=".sty") fileName+=".tex";
   startPlainFile(fileName);
+  m_codeGen.setTextStream(t);
+  m_codeGen.setRelativePath(relPath);
+  m_codeGen.setSourceFileName(stripPath(fileName));
 }
 
 void LatexGenerator::endFile()
 {
   endPlainFile();
-  sourceFileName.resize(0);
+  m_codeGen.setSourceFileName("");
 }
 
 //void LatexGenerator::writeIndex()
@@ -604,14 +822,6 @@ void LatexGenerator::startProjectNumber()
   t << "\\\\[1ex]\\large "; 
 }
 
-static QCString convertToLaTeX(const QCString &s)
-{
-  QGString result;
-  FTextStream t(&result);
-  filterLatexString(t,s,FALSE,FALSE,FALSE);
-  return result.data();
-}
-
 void LatexGenerator::startIndexSection(IndexSections is)
 {
   bool &compactLatex = Config_getBool("COMPACT_LATEX");
@@ -1087,7 +1297,7 @@ void LatexGenerator::endIndexItem(const char *ref,const char *fn)
 {
   if (!ref && fn)
   {
-    t << "}{\\pageref{" << fn << "}}{}" << endl;
+    t << "}{\\pageref{" << stripPath(fn) << "}}{}" << endl;
   }
 }
 
@@ -1194,7 +1404,8 @@ void LatexGenerator::endTextLink()
 void LatexGenerator::writeObjectLink(const char *ref, const char *f,
                                      const char *anchor, const char *text)
 {
-  if (!disableLinks && !ref && Config_getBool("PDF_HYPERLINKS"))
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
+  if (!disableLinks && !ref && pdfHyperlinks)
   {
     t << "\\hyperlink{";
     if (f) t << stripPath(f);
@@ -1225,34 +1436,6 @@ void LatexGenerator::endPageRef(const char *clname, const char *anchor)
   t << "}";
 }
 
-void LatexGenerator::writeCodeLink(const char *ref,const char *f,
-                                   const char *anchor,const char *name,
-                                   const char *)
-{
-  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
-  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
-  int l = qstrlen(name);
-  if (col+l>80)
-  {
-    t << "\n      ";
-    col=0;
-  }
-  if (/*m_prettyCode &&*/ !disableLinks && !ref && usePDFLatex && pdfHyperlinks)
-  {
-    t << "\\hyperlink{";
-    if (f) t << stripPath(f);
-    if (f && anchor) t << "_"; 
-    if (anchor) t << anchor; 
-    t << "}{";
-    codify(name);
-    t << "}";
-  }
-  else
-  {
-    t << name;
-  }
-  col+=l;
-}
 
 void LatexGenerator::startTitleHead(const char *fileName)
 {
@@ -1260,7 +1443,7 @@ void LatexGenerator::startTitleHead(const char *fileName)
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   if (usePDFLatex && pdfHyperlinks && fileName)
   {
-    t << "\\hypertarget{" << stripPath(fileName) << "}{";
+    t << "\\hypertarget{" << stripPath(fileName) << "}{}";
   }
   if (Config_getBool("COMPACT_LATEX")) 
   {
@@ -1274,21 +1457,15 @@ void LatexGenerator::startTitleHead(const char *fileName)
 
 void LatexGenerator::endTitleHead(const char *fileName,const char *name)
 {
-  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
-  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   t << "}" << endl;
   if (name)
   {
     t << "\\label{" << stripPath(fileName) << "}\\index{";
-    escapeLabelName(name);
+    t << latexEscapeLabelName(name,insideTabbing);
     t << "@{";
-    escapeMakeIndexChars(name);
+    t << latexEscapeIndexChars(name,insideTabbing);
     t << "}}" << endl;
   }
-  if (usePDFLatex && pdfHyperlinks && fileName)
-  {
-    t << "}" << endl;
-  }
 }
 
 void LatexGenerator::startTitle()
@@ -1365,53 +1542,56 @@ void LatexGenerator::startMemberDoc(const char *clname,
     t << "\\index{";
     if (clname)
     {
-      escapeLabelName(clname);
+      t << latexEscapeLabelName(clname,insideTabbing);
       t << "@{";
-      escapeMakeIndexChars(clname);
+      t << latexEscapeIndexChars(clname,insideTabbing);
       t << "}!";
     }
-    escapeLabelName(memname);
+    t << latexEscapeLabelName(memname,insideTabbing);
     t << "@{";
-    escapeMakeIndexChars(memname);
+    t << latexEscapeIndexChars(memname,insideTabbing);
     t << "}}" << endl;
 
     t << "\\index{";
-    escapeLabelName(memname);
+    t << latexEscapeLabelName(memname,insideTabbing);
     t << "@{";
-    escapeMakeIndexChars(memname);
+    t << latexEscapeIndexChars(memname,insideTabbing);
     t << "}";
     if (clname)
     {
       t << "!";
-      escapeLabelName(clname);
+      t << latexEscapeLabelName(clname,insideTabbing);
       t << "@{";
-      escapeMakeIndexChars(clname);
+      t << latexEscapeIndexChars(clname,insideTabbing);
       t << "}"; 
     }
     t << "}" << endl;
   }
   static const char *levelLab[] = { "subsubsection","paragraph","subparagraph", "subparagraph" };
   static bool compactLatex = Config_getBool("COMPACT_LATEX");
+  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
   int level=0;
   if (showInline) level+=2;
   if (compactLatex) level++;
   t << "\\" << levelLab[level]; 
 
-  //if (Config_getBool("PDF_HYPERLINKS") && memname) 
-  //{
-  //  t << "["; 
-  //  escapeMakeIndexChars(this,t,memname);
-  //  t << "]";
-  //}
   t << "[{";
-  escapeMakeIndexChars(title);
+  if (pdfHyperlinks)
+  {
+    t << "\\texorpdfstring{";
+  }
+  t << latexEscapeIndexChars(title,insideTabbing);
+  if (pdfHyperlinks)
+  {
+    t << "}{" << latexEscapePDFString(title) << "}";
+  }
   t << "}]";
   t << "{\\setlength{\\rightskip}{0pt plus 5cm}";
   disableLinks=TRUE;
 }
 
-void LatexGenerator::endMemberDoc(bool) 
-{ 
+void LatexGenerator::endMemberDoc(bool)
+{
   disableLinks=FALSE;
   t << "}";
   //if (Config_getBool("COMPACT_LATEX")) t << "\\hfill";
@@ -1421,15 +1601,6 @@ void LatexGenerator::startDoxyAnchor(const char *fName,const char *,
                                      const char *anchor, const char *,
                                      const char *)
 {
-  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
-  static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
-  if (usePDFLatex && pdfHyperlinks)
-  {
-    t << "\\hypertarget{";
-    if (fName) t << stripPath(fName);
-    if (anchor) t << "_" << anchor;
-    t << "}{";
-  }
 }
 
 void LatexGenerator::endDoxyAnchor(const char *fName,const char *anchor)
@@ -1438,7 +1609,10 @@ void LatexGenerator::endDoxyAnchor(const char *fName,const char *anchor)
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   if (usePDFLatex && pdfHyperlinks)
   {
-    t << "}";
+    t << "\\hypertarget{";
+    if (fName) t << stripPath(fName);
+    if (anchor) t << "_" << anchor;
+    t << "}{}";
   }
   t << "\\label{";
   if (fName) t << stripPath(fName);
@@ -1449,18 +1623,18 @@ void LatexGenerator::endDoxyAnchor(const char *fName,const char *anchor)
 void LatexGenerator::writeAnchor(const char *fName,const char *name)
 { 
   //printf("LatexGenerator::writeAnchor(%s,%s)\n",fName,name);
-  t << "\\label{" << name << "}" << endl; 
+  t << "\\label{" << stripPath(name) << "}" << endl; 
   static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
   static bool usePDFLatex   = Config_getBool("USE_PDFLATEX");
   if (usePDFLatex && pdfHyperlinks)
   {
     if (fName)
     {
-      t << "\\hypertarget{" << stripPath(fName) << "_" << name << "}{}" << endl;
+      t << "\\hypertarget{" << stripPath(fName) << "_" << stripPath(name) << "}{}" << endl;
     }
     else
     {
-      t << "\\hypertarget{" << name << "}{}" << endl;
+      t << "\\hypertarget{" << stripPath(name) << "}{}" << endl;
     }
   }
 }
@@ -1476,16 +1650,16 @@ void LatexGenerator::addIndexItem(const char *s1,const char *s2)
   if (s1)
   {
     t << "\\index{";
-    escapeLabelName(s1);
+    t << latexEscapeLabelName(s1,insideTabbing);
     t << "@{";
-    escapeMakeIndexChars(s1);
+    t << latexEscapeIndexChars(s1,insideTabbing);
     t << "}";
     if (s2)
     {
       t << "!";
-      escapeLabelName(s2);
+      t << latexEscapeLabelName(s2,insideTabbing);
       t << "@{";
-      escapeMakeIndexChars(s2);
+      t << latexEscapeIndexChars(s2,insideTabbing);
       t << "}";
     }
     t << "}";
@@ -1541,94 +1715,6 @@ void LatexGenerator::docify(const char *str)
   filterLatexString(t,str,insideTabbing,FALSE,FALSE);
 }
 
-void LatexGenerator::codify(const char *str)
-{
-  if (str)
-  { 
-    const char *p=str;
-    char c;
-    //char cs[5];
-    int spacesToNextTabStop;
-    static int tabSize = Config_getInt("TAB_SIZE");
-    const int maxLineLen = 108;
-    QCString result(4*maxLineLen+1); // worst case for 1 line of 4-byte chars
-    int i;
-    while ((c=*p))
-    {
-      switch(c)
-      {
-        case 0x0c: p++;  // remove ^L
-                   break;
-        case '\t': spacesToNextTabStop =
-                         tabSize - (col%tabSize);
-                   t << Doxygen::spaces.left(spacesToNextTabStop); 
-                   col+=spacesToNextTabStop;
-                   p++;
-                   break; 
-        case '\n': t << '\n'; col=0; p++;
-                   break;
-        default:   
-                   i=0;
-
-#undef  COPYCHAR
-// helper macro to copy a single utf8 character, dealing with multibyte chars.
-#define COPYCHAR() do {                                           \
-                     result[i++]=c; p++;                          \
-                     if (c<0) /* multibyte utf-8 character */     \
-                     {                                            \
-                       /* 1xxx.xxxx: >=2 byte character */        \
-                       result[i++]=*p++;                          \
-                       if (((uchar)c&0xE0)==0xE0)                 \
-                       {                                          \
-                         /* 111x.xxxx: >=3 byte character */      \
-                         result[i++]=*p++;                        \
-                       }                                          \
-                       if (((uchar)c&0xF0)==0xF0)                 \
-                       {                                          \
-                         /* 1111.xxxx: 4 byte character */        \
-                         result[i++]=*p++;                        \
-                       }                                          \
-                     }                                            \
-                     col++;                                       \
-                   } while(0)
-
-                   // gather characters until we find whitespace or are at
-                   // the end of a line
-                   COPYCHAR();
-                   if (col>=maxLineLen) // force line break
-                   {
-                     t << "\n      ";
-                     col=0;
-                   }
-                   else // copy more characters
-                   {
-                     while (col<maxLineLen && (c=*p) && 
-                            c!=0x0c && c!='\t' && c!='\n' && c!=' '
-                           )
-                     {
-                       COPYCHAR();
-                     }
-                     if (col>=maxLineLen) // force line break
-                     {
-                       t << "\n      ";
-                       col=0;
-                     }
-                   }
-                   result[i]=0; // add terminator
-                   //if (m_prettyCode)
-                   //{
-                     filterLatexString(t,result,insideTabbing,TRUE);
-                   //}
-                   //else
-                   //{
-                   //  t << result;
-                   //}
-                   break;
-      }
-    }
-  }
-}
-
 void LatexGenerator::writeChar(char c)
 {
   char cs[2];
@@ -1964,10 +2050,10 @@ void LatexGenerator::exceptionEntry(const char* prefix,bool closeBracket)
 
 void LatexGenerator::writeDoc(DocNode *n,Definition *ctx,MemberDef *)
 {
-  LatexDocVisitor *visitor = 
+  LatexDocVisitor *visitor =
     new LatexDocVisitor(t,*this,ctx?ctx->getDefFileExtension():QCString(""),insideTabbing);
   n->accept(visitor);
-  delete visitor; 
+  delete visitor;
 }
 
 void LatexGenerator::startConstraintList(const char *header)
@@ -2011,76 +2097,6 @@ void LatexGenerator::endConstraintList()
   t << "\\end{Desc}" << endl;
 }
 
-void LatexGenerator::escapeLabelName(const char *s)
-{
-  if (s==0) return;
-  const char *p=s;
-  char c;
-  QCString result(qstrlen(s)+1); // worst case allocation
-  int i;
-  while ((c=*p++))
-  {
-    switch (c)
-    {
-      case '|': t << "\\texttt{\"|}"; break;
-      case '!': t << "\"!"; break;
-      case '%': t << "\\%";       break;
-      case '{': t << "\\lcurly{}"; break;
-      case '}': t << "\\rcurly{}"; break;
-      case '~': t << "````~"; break; // to get it a bit better in index together with other special characters
-      // NOTE: adding a case here, means adding it to while below as well!
-      default:  
-        i=0;
-        // collect as long string as possible, before handing it to docify
-        result[i++]=c;
-        while ((c=*p) && c!='|' && c!='!' && c!='%' && c!='{' && c!='}' && c!='~')
-        {
-          result[i++]=c;
-          p++;
-        }
-        result[i]=0;
-        docify(result); 
-        break;
-    }
-  }
-}
-
-void LatexGenerator::escapeMakeIndexChars(const char *s)
-{
-  if (s==0) return;
-  const char *p=s;
-  char c;
-  QCString result(qstrlen(s)+1); // worst case allocation
-  int i;
-  while ((c=*p++))
-  {
-    switch (c)
-    {
-      case '!': t << "\"!"; break;
-      case '"': t << "\"\""; break;
-      case '@': t << "\"@"; break;
-      case '|': t << "\\texttt{\"|}"; break;
-      case '[': t << "["; break;
-      case ']': t << "]"; break;
-      case '{': t << "\\lcurly{}"; break;
-      case '}': t << "\\rcurly{}"; break;
-      // NOTE: adding a case here, means adding it to while below as well!
-      default:  
-        i=0;
-        // collect as long string as possible, before handing it to docify
-        result[i++]=c;
-        while ((c=*p) && c!='"' && c!='@' && c!='[' && c!=']' && c!='!' && c!='{' && c!='}' && c!='|')
-        {
-          result[i++]=c;
-          p++;
-        }
-        result[i]=0;
-        docify(result); 
-        break;
-    }
-  }
-}
-
 void LatexGenerator::startCodeFragment()
 {
   t << "\n\\begin{DoxyCode}\n";
@@ -2091,61 +2107,6 @@ void LatexGenerator::endCodeFragment()
   t << "\\end{DoxyCode}\n";
 }
 
-void LatexGenerator::writeLineNumber(const char *ref,const char *fileName,const char *anchor,int l)
-{
-  static bool usePDFLatex = Config_getBool("USE_PDFLATEX");
-  static bool pdfHyperlinks = Config_getBool("PDF_HYPERLINKS");
-  if (m_prettyCode)
-  {
-    QCString lineNumber;
-    lineNumber.sprintf("%05d",l);
-
-    if (fileName && !sourceFileName.isEmpty())
-    {
-      QCString lineAnchor;
-      lineAnchor.sprintf("_l%05d",l);
-      lineAnchor.prepend(sourceFileName);
-      //if (!m_prettyCode) return;
-      if (usePDFLatex && pdfHyperlinks)
-      {
-        t << "\\hypertarget{" << stripPath(lineAnchor) << "}{}";
-      }
-      writeCodeLink(ref,fileName,anchor,lineNumber,0);
-    }
-    else
-    { 
-      codify(lineNumber);
-    }
-    t << " ";
-  }
-  else
-  {
-    t << l << " ";
-  }
-}
-
-void LatexGenerator::startCodeLine(bool)
-{
-  col=0;
-}
-
-void LatexGenerator::endCodeLine()
-{
-  codify("\n");
-}
-
-void LatexGenerator::startFontClass(const char *name)
-{
-  //if (!m_prettyCode) return;
-  t << "\\textcolor{" << name << "}{";
-}
-
-void LatexGenerator::endFontClass()
-{
-  //if (!m_prettyCode) return;
-  t << "}";
-}
-
 void LatexGenerator::startInlineHeader()
 {
   if (Config_getBool("COMPACT_LATEX")) 
@@ -2229,3 +2190,4 @@ void LatexGenerator::endLabels()
 {
 }
 
+
