@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -107,7 +107,6 @@ ManGenerator::~ManGenerator()
 
 void ManGenerator::init()
 {
-  QCString ext = getExtension();
   QCString &manOutput = Config_getString("MAN_OUTPUT");
   
   QDir d(manOutput);
@@ -194,6 +193,7 @@ void ManGenerator::endTitleHead(const char *,const char *name)
   t << ".SH NAME" << endl;
   t << name << " \\- ";
   firstCol=FALSE;
+  paragraph=TRUE;
   inHeader=TRUE;
 }
 
@@ -306,6 +306,7 @@ void ManGenerator::docify(const char *str)
     {
       switch(c)
       {
+        case '-':  t << "\\-"; break; // see  bug747780
         case '.':  t << "\\&."; break; // see  bug652277
         case '\\': t << "\\\\"; col++; break;
         case '\n': t << "\n"; col=0; break;
@@ -340,7 +341,7 @@ void ManGenerator::codify(const char *str)
                     break;
         case '\n':  t << "\n"; firstCol=TRUE; col=0; break;
         case '\\':  t << "\\"; col++; break;
-        case '\"':  c = '\''; // no break!
+        case '\"':  // no break!
         default:    p=writeUtf8Char(t,p-1); firstCol=FALSE; col++; break;
       }
     }
@@ -828,10 +829,4 @@ void ManGenerator::endLabels()
 
 void ManGenerator::endHeaderSection()
 {
-  if (!firstCol) 
-  { 
-    t<< endl; firstCol=TRUE; 
-  }
 }
-
-
