@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -176,6 +176,7 @@ class MemberDef : public Definition
     bool protectionVisible() const;
     bool showInCallGraph() const;
     bool isStrongEnumValue() const;
+    bool livesInsideEnum() const;
 
     // derived getters
     bool isFriendToHide() const;
@@ -188,6 +189,7 @@ class MemberDef : public Definition
     bool isLinkable() const;
     bool hasDocumentation() const;  // overrides hasDocumentation in definition.h
     //bool hasUserDocumentation() const; // overrides hasUserDocumentation
+    bool isDeleted() const;
     bool isBriefSectionVisible() const;
     bool isDetailedSectionVisible(bool inGroup,bool inFile) const;
     bool isDetailedSectionLinkable() const;
@@ -263,6 +265,7 @@ class MemberDef : public Definition
     QCString documentation() const;
     QCString briefDescription(bool abbr=FALSE) const;
     QCString fieldType() const;
+    bool isReference() const;
 
 
     //-----------------------------------------------------------------------------------
@@ -376,16 +379,15 @@ class MemberDef : public Definition
     // output generation
     void writeDeclaration(OutputList &ol,
                    ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
-                   bool inGroup, const DefType compoundType,
-                   ClassDef *inheritFrom=0,const char *inheritId=0); 
+                   bool inGroup, ClassDef *inheritFrom=0,const char *inheritId=0); 
     void writeDocumentation(MemberList *ml,OutputList &ol,
                             const char *scopeName,Definition *container,
                             bool inGroup,bool showEnumValues=FALSE,bool
                             showInline=FALSE);
     void writeMemberDocSimple(OutputList &ol,Definition *container);
     void writeEnumDeclaration(OutputList &typeDecl,
-            ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd, 
-            const DefType compoundType);
+            ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
+    void writeTagFile(FTextStream &);
     void warnIfUndocumented();
     
     MemberDef *createTemplateInstanceMember(ArgumentList *formalArgs,
