@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -33,6 +33,7 @@ class GroupDef;
 class OutputList;
 class Definition;
 class StorageIntf;
+class FTextStream;
 struct ListItemInfo;
 
 /** A class representing a group of members. */
@@ -41,7 +42,7 @@ class MemberGroup
   public:
     MemberGroup();
     MemberGroup(Definition *parent,int id,const char *header,
-                const char *docs,const char *docFile);
+                const char *docs,const char *docFile,int docLine);
    ~MemberGroup();
     QCString header() const { return grpHeader; }
     int groupId() const { return grpId; }
@@ -57,11 +58,12 @@ class MemberGroup
                Definition *container,bool showEnumValues,bool showInline);
     void writeDocumentationPage(OutputList &ol,const char *scopeName,
                Definition *container);
+    void writeTagFile(FTextStream &);
     void addGroupedInheritedMembers(OutputList &ol,ClassDef *cd,
                MemberListType lt,
                ClassDef *inheritedFrom,const QCString &inheritId);
 
-    QCString documentation() const { return doc; }
+    const QCString &documentation() const { return doc; }
     bool allMembersInSameSection() const { return inSameSection; }
     void addToDeclarationSection();
     int countDecMembers(GroupDef *gd=0);
@@ -87,6 +89,9 @@ class MemberGroup
     Definition *parent() const { return m_parent; }
     QCString anchor() const;
 
+    QCString docFile() const { return m_docFile; }
+    int docLine() const { return m_docLine; }
+
     void marshal(StorageIntf *s);
     void unmarshal(StorageIntf *s);
 
@@ -103,6 +108,7 @@ class MemberGroup
     int  m_numDocMembers;
     Definition *m_parent;
     QCString m_docFile;
+    int m_docLine;
     QList<ListItemInfo> *m_xrefListItems;
 };
 
@@ -135,12 +141,13 @@ class MemberGroupSDict : public SIntDict<MemberGroup>
 /** Data collected for a member group */
 struct MemberGroupInfo
 {
-  MemberGroupInfo() : m_sli(0) {}
+  MemberGroupInfo() : m_sli(0), docLine(-1) {}
  ~MemberGroupInfo() { delete m_sli; m_sli=0; }
   void setRefItems(const QList<ListItemInfo> *sli);
   QCString header;
   QCString doc;
   QCString docFile;
+  int docLine;
   QCString compoundName;
   QList<ListItemInfo> *m_sli;
 };
