@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -69,10 +69,10 @@ void initWarningFormat()
 //  {
 //    warnFormatOrder = 6;
 //  }
-//  outputFormat = 
+//  outputFormat =
 //      substitute(
 //        substitute(
-//          substitute( 
+//          substitute(
 //            Config_getString("WARN_FORMAT"),
 //           "$file","%s"
 //          ),
@@ -96,6 +96,11 @@ void initWarningFormat()
   {
     warnFile = stderr;
   }
+
+  if (Config_getBool("WARN_AS_ERROR"))
+  {
+    warning_str = error_str;
+  }
 }
 
 
@@ -130,37 +135,48 @@ static void format_warn(const char *file,int line,const char *text)
     }
   }
   // substitute markers by actual values
-  QCString msgText = 
+  bool warnAsError = Config_getBool("WARN_AS_ERROR");
+  QCString msgText =
       substitute(
         substitute(
           substitute(
-            substitute( 
+            substitute(
               outputFormat,
               "$file",fileSubst
             ),
-            "$text",textSubst
+            "$line",lineSubst
           ),
-          "$line",lineSubst
+          "$version",versionSubst
         ),
-        "$version",versionSubst
-      )+'\n';
+        "$text",textSubst
+      );
+  if (warnAsError)
+  {
+    msgText += " (warning treated as error, aborting now)";
+  }
+  msgText += '\n';
 
   // print resulting message
   fwrite(msgText.data(),1,msgText.length(),warnFile);
+  if (warnAsError)
+  {
+    exit(1);
+  }
 }
 
 static void do_warn(const char *tag, const char *file, int line, const char *prefix, const char *fmt, va_list args)
 {
-  if (!Config_getBool(tag)) return; // warning type disabled
-  char text[40960];
+  if (tag && !Config_getBool(tag)) return; // warning type disabled
+  const int bufSize = 40960;
+  char text[bufSize];
   int l=0;
   if (prefix)
   {
-    strcpy(text,prefix);
+    qstrncpy(text,prefix,bufSize);
     l=strlen(prefix);
   }
-  vsnprintf(text+l, 40960-l, fmt, args);
-  text[40960-1]='\0';
+  vsnprintf(text+l, bufSize-l, fmt, args);
+  text[bufSize-1]='\0';
   format_warn(file,line,text);
 }
 
@@ -169,7 +185,7 @@ void warn(const char *file,int line,const char *fmt, ...)
   va_list args;
   va_start(args, fmt);
   do_warn("WARNINGS", file, line, warning_str, fmt, args);
-  va_end(args); 
+  va_end(args);
 }
 
 void va_warn(const char *file,int line,const char *fmt,va_list args)
@@ -190,7 +206,7 @@ void warn_undoc(const char *file,int line,const char *fmt, ...)
   do_warn("WARN_IF_UNDOCUMENTED", file, line, warning_str, fmt, args);
   va_end(args);
 }
-  
+
 void warn_doc_error(const char *file,int line,const char *fmt, ...)
 {
   va_list args;
@@ -204,7 +220,7 @@ void warn_uncond(const char *fmt, ...)
   va_list args;
   va_start(args, fmt);
   vfprintf(warnFile, (QCString(warning_str) + fmt).data(), args);
-  va_end(args); 
+  va_end(args);
 }
 
 void err(const char *fmt, ...)
@@ -212,7 +228,15 @@ void err(const char *fmt, ...)
   va_list args;
   va_start(args, fmt);
   vfprintf(warnFile, (QCString(error_str) + fmt).data(), args);
-  va_end(args); 
+  va_end(args);
+}
+
+extern void err_full(const char *file,int line,const char *fmt, ...)
+{
+  va_list args;
+  va_start(args, fmt);
+  do_warn(NULL, file, line, error_str, fmt, args);
+  va_end(args);
 }
 
 void printlex(int dbg, bool enter, const char *lexName, const char *fileName)
@@ -229,15 +253,15 @@ void printlex(int dbg, bool enter, const char *lexName, const char *fileName)
   if (dbg)
   {
     if (fileName)
-      fprintf(stderr,"--%s lexical analyzer: %s (for: %s)\n",enter_txt, lexName, fileName);
+      fprintf(stderr,"--%s lexical analyzer: %s (for: %s)\n",enter_txt, qPrint(lexName), qPrint(fileName));
     else
-      fprintf(stderr,"--%s lexical analyzer: %s\n",enter_txt, lexName);
+      fprintf(stderr,"--%s lexical analyzer: %s\n",enter_txt, qPrint(lexName));
   }
   else
   {
     if (fileName)
-      Debug::print(Debug::Lex,0,"%s lexical analyzer: %s (for: %s)\n",enter_txt_uc, lexName, fileName);
+      Debug::print(Debug::Lex,0,"%s lexical analyzer: %s (for: %s)\n",enter_txt_uc, qPrint(lexName), qPrint(fileName));
     else
-      Debug::print(Debug::Lex,0,"%s lexical analyzer: %s\n",enter_txt_uc, lexName);
+      Debug::print(Debug::Lex,0,"%s lexical analyzer: %s\n",enter_txt_uc, qPrint(lexName));
   }
 }
