@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -74,6 +74,7 @@ static bool convertMapFile(FTextStream &t,const char *mapName,const QCString rel
         t << externalRef(relPath,df->ref(),TRUE);
         if (!df->file().isEmpty()) t << df->file() << Doxygen::htmlFileExtension;
         if (!df->anchor().isEmpty()) t << "#" << df->anchor();
+        delete df;
       }
       else
       {
@@ -168,7 +169,6 @@ QCString getMscImageMapFromFile(const QCString& inFile, const QCString& outDir,
   QCString mscExe = Config_getString("MSCGEN_PATH")+"mscgen"+portable_commandExtension();
   QCString mscArgs = "-T ismap -i \"";
   mscArgs+=inFile;
-  QFileInfo fi(inFile);
   mscArgs+="\" -o \"";
   mscArgs+=outFile + "\"";
 
@@ -200,7 +200,6 @@ void writeMscImageMapFromFile(FTextStream &t,const QCString &inFile,
  			    )
 {
   QCString mapName = baseName+".map";
-  QCString mapFile = inFile+".map";
   t << "<img src=\"" << relPath << baseName << ".";
   switch (format)
   {
