@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -58,7 +58,7 @@ class OutputList : public OutputDocInterface
     virtual ~OutputList();
 
     void add(const OutputGenerator *);
-    uint count() const { return outputs->count(); }
+    uint count() const { return m_outputs.count(); }
     
     void disableAllBut(OutputGenerator::OutputType o);
     void enableAll();
@@ -483,28 +483,28 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::addWord,word,hiPriority); }
 
     void startPlainFile(const char *name)
-    { 
-      OutputGenerator *og=outputs->first();
-      while (og)
+    {
+      QListIterator<OutputGenerator> it(m_outputs);
+      OutputGenerator *og;
+      for (;(og=it.current());++it)
       {
         if (og->isEnabled()) (og->startPlainFile)(name);
-        og=outputs->next();
       }
     }
-    void endPlainFile() 
-    { 
-      OutputGenerator *og=outputs->first();
-      while (og)
+    void endPlainFile()
+    {
+      QListIterator<OutputGenerator> it(m_outputs);
+      OutputGenerator *og;
+      for (;(og=it.current());++it)
       {
         if (og->isEnabled()) (og->endPlainFile)();
-        og=outputs->next();
       }
     }
 
   private:
     void debug();
     void clear();
-    
+
     void forall(void (OutputGenerator::*func)());
     FORALLPROTO1(const char *);
     FORALLPROTO1(char);
@@ -546,9 +546,9 @@ class OutputList : public OutputDocInterface
     FORALLPROTO5(const char *,const char *,const char *,const char *,bool);
     FORALLPROTO6(const char *,const char *,const char *,const char *,const char *,const char *);
     FORALLPROTO6(const char *,const DocLinkInfo &,const char *,const char *,const SourceLinkInfo &,const SourceLinkInfo &);
-  
+
     OutputList(const OutputList &ol);
-    QList<OutputGenerator> *outputs;
+    QList<OutputGenerator> m_outputs;
 };
 
 #endif
