@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,8 @@ PageDef::PageDef(const char *f,int l,const char *n,
   m_subPageDict = new PageSDict(7);
   m_pageScope = 0;
   m_nestingLevel = 0;
+  static bool shortNames = Config_getBool("SHORT_NAMES");
+  m_fileName = shortNames ? convertNameToFile(n) : QCString(n);
   m_showToc = FALSE;
 }
 
@@ -61,20 +63,11 @@ QCString PageDef::getOutputFileBase() const
     return m_fileName; 
 }
 
-void PageDef::setFileName(const char *name,bool dontEscape) 
-{ 
-  static bool shortNames = Config_getBool("SHORT_NAMES");
-  if (shortNames && !dontEscape)
-  {
-    m_fileName = convertNameToFile(name);
-  }
-  else
-  {
-    m_fileName = name; 
-  }
+void PageDef::setFileName(const char *name)
+{
+  m_fileName = name;
 }
 
-
 void PageDef::addInnerCompound(Definition *def)
 {
   if (def->definitionType()==Definition::TypePage)
@@ -99,6 +92,30 @@ bool PageDef::hasParentPage() const
          getOuterScope()->definitionType()==Definition::TypePage;
 }
 
+void PageDef::writeTagFile(FTextStream &tagFile)
+{
+  bool found = name()=="citelist";
+  QDictIterator<RefList> rli(*Doxygen::xrefLists);
+  RefList *rl;
+  for (rli.toFirst();(rl=rli.current()) && !found;++rli)
+  {
+    if (rl->listName()==name())
+    {
+      found=TRUE;
+      break;
+    }
+  }
+  if (!found) // not one of the generated related pages
+  {
+    tagFile << "  <compound kind=\"page\">" << endl;
+    tagFile << "    <name>" << name() << "</name>" << endl;
+    tagFile << "    <title>" << convertToXML(title()) << "</title>" << endl;
+    tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << "</filename>" << endl;
+    writeDocAnchorsToTagFile(tagFile);
+    tagFile << "  </compound>" << endl;
+  }
+}
+
 void PageDef::writeDocumentation(OutputList &ol)
 {
   static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
@@ -200,30 +217,6 @@ void PageDef::writeDocumentation(OutputList &ol)
   ol.popGeneratorState();
   //1.}
 
-  if (!Config_getString("GENERATE_TAGFILE").isEmpty())
-  {
-    bool found = name()=="citelist";
-    QDictIterator<RefList> rli(*Doxygen::xrefLists);
-    RefList *rl;
-    for (rli.toFirst();(rl=rli.current()) && !found;++rli)
-    {
-      if (rl->listName()==name())
-      {
-        found=TRUE;
-        break;
-      }
-    }
-    if (!found) // not one of the generated related pages
-    {
-      Doxygen::tagFile << "  <compound kind=\"page\">" << endl;
-      Doxygen::tagFile << "    <name>" << name() << "</name>" << endl;
-      Doxygen::tagFile << "    <title>" << convertToXML(title()) << "</title>" << endl;
-      Doxygen::tagFile << "    <filename>" << getOutputFileBase() << "</filename>" << endl;
-      writeDocAnchorsToTagFile();
-      Doxygen::tagFile << "  </compound>" << endl;
-    }
-  }
-
   Doxygen::indexList->addIndexItem(this,0,0,filterTitle(title()));
 }
 
