@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -1116,7 +1116,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
         "};\n"
         "\\endcode\n"
         "Dies liefert den folgenden Graphen:"
-        "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center></p>\n"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center></p>\n"
         "<p>\n"
         "Die Rechtecke in obigem Graphen bedeuten:\n"
         "</p>\n"
@@ -1995,7 +1995,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trProvidedByCategory()
     {
-      return "Bestandteil der Kategorie @1.";
+      return "Bestandteil der Kategorie @0.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -2004,7 +2004,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trExtendsClass()
     {
-      return "Erweitert Klasse @1.";
+      return "Erweitert Klasse @0.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
