@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -1045,7 +1045,7 @@ class TranslatorSpanish : public Translator
         "};\n"
         "\\endcode\n"
         "Dará como resultado el siguiente gráfico:"
-        "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center></p>\n"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center></p>\n"
         "<p>\n"
         "Las cajas en el gráfico arriba tienen el siguiente significado:\n"
         "</p>\n"
@@ -1957,7 +1957,7 @@ class TranslatorSpanish : public Translator
      */
     virtual QCString trProvidedByCategory()
     {
-      return "Proporcionado por categoría @1.";
+      return "Proporcionado por categoría @0.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -1966,7 +1966,7 @@ class TranslatorSpanish : public Translator
      */
     virtual QCString trExtendsClass()
     {
-      return "Extiende la clase @1.";
+      return "Extiende la clase @0.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
