@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -1037,7 +1037,7 @@ class TranslatorJapanese : public Translator
         "\\c MAX_DOT_GRAPH_" /* わざわざちょん切っているのは doc/translator.py の検出回避のため */
         "HEIGHT タグに 200 を与えた設定ファイル"
         "を使うと、次のようなグラフとなります。"
-        "<p><center><img src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+        "<p><center><img src=\"graph_legend."+getDotImageExtension()+"\"></center>\n"
         "<p>\n"
         "グラフ内の矩形は構造体やクラスを表しています。色の意味は次の通りです。\n"
         "<ul>\n"
@@ -1878,7 +1878,7 @@ class TranslatorJapanese : public Translator
      */
     virtual QCString trProvidedByCategory()
     {
-      return "@1 カテゴリーから提供されています。";
+      return "@0 カテゴリーから提供されています。";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -1887,7 +1887,7 @@ class TranslatorJapanese : public Translator
      */
     virtual QCString trExtendsClass()
     {
-      return "@1 を拡張しています。";
+      return "@0 を拡張しています。";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
