@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2013 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -21,6 +21,7 @@ Svensk översättning av:
 Samuel Hägglund      <sahag96@ite.mh.se>
 Xet Erixon           <xet@xeqt.com>
 Mikael Hallin        <mikaelhallin@yahoo.se>           2003-07-28
+Björn Palmqvist      <bjorn@aidium.se>                 2014-02-01
 ==================================================================================
 Uppdateringar.
 1999/04/29
@@ -64,12 +65,14 @@ Problem!
    Deprecated: nån hygglig svensk översättning???
 
    Skicka gärna synpunkter.
+2015/01/09
+* Uppdaterat den till senaste versionen 1.8.9.1
 */
 
 #ifndef TRANSLATOR_SE_H
 #define TRANSLATOR_SE_H
 
-class TranslatorSwedish : public TranslatorAdapter_1_6_0
+class TranslatorSwedish : public Translator
 {
   public:
 
@@ -389,7 +392,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
     { return "Dokumentation över typdefinitioner"; }
 
     virtual QCString trEnumerationTypeDocumentation()
-    { return "Dokumentation över egenuppräknande typer"; }
+    { return "Dokumentation över egenuppräknande typer"; ; }
 
     virtual QCString trFunctionDocumentation()
     { return "Dokumentation över funktioner"; }
@@ -490,8 +493,8 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
         case ClassDef::Struct: result+=" strukt"; break;
         case ClassDef::Union:  result+=" union"; break;
         case ClassDef::Interface:  result+=" gränssnitt"; break;
-        case ClassDef::Protocol:   result+=" protocol"; break; // translate me!
-        case ClassDef::Category:   result+=" category"; break; // translate me!
+        case ClassDef::Protocol:   result+=" protokoll"; break;
+        case ClassDef::Category:   result+=" kategori"; break;
         case ClassDef::Exception:  result+=" undantag"; break;
         default: break;
       }
@@ -632,8 +635,8 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
         case ClassDef::Struct:     result+="denna strukt "; break;
         case ClassDef::Union:      result+="denna union "; break;
         case ClassDef::Interface:  result+="detta gränssnitt "; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+="detta protokoll"; break;
+        case ClassDef::Category:   result+="denna kategori"; break;
         case ClassDef::Exception:  result+="detta undantag "; break;
         default: break;
       }
@@ -876,9 +879,9 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
         "genererar.<p>\n"
         "Tag följande exempel:\n"
         "\\code\n"
-	"/*! Osynlig klass på grund av stympning */\n"
+	"/*! Osynlig klass på grund av trunkering */\n"
         "class Invisible { };\n\n"
-	"/*! Stympad klass, ärvningsrelationen är dold */\n"
+	"/*! Trunkerad klass, ärvningsrelationen är dold */\n"
         "class Truncated : public Invisible { };\n\n"
 	"/* Klass utan doxygen-kommentarer */\n"
         "class Undocumented { };\n\n"
@@ -903,34 +906,33 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
         "    Used *m_usedClass;\n"
         "};\n"
         "\\endcode\n"
-	"Om \\c MAX_DOT_GRAPH_HEIGHT är satt till 240 i konfigurationsfilen, "
-	"kommer följande graf att generas:"
-        "<p><center><img alt=\"\" src=\"graph_legend."+Config_getEnum("DOT_IMAGE_FORMAT")+"\"></center>\n"
+	"Detta resulterar i att följande graf genereras:"
+        "<p><center><img alt=\"\" src=\"graph_legend."+getDotImageExtension()+"\"></center></p>\n"
         "<p>\n"
 	"Rektanglarna i den ovanstående grafen har följande betydelser:\n"
         "<ul>\n"
-	"<li>%En fylld svart rektangel representerar den strukt eller klass "
-	"som har genererat grafen.\n"
-	"<li>%En rektangel med svart kant symboliserar en dokumenterad "
-	"strukt eller klass.\n"
-	"<li>%En rektangel med grå kant symboliserar en odokumenterad strukt "
-	"eller klass.\n"
+	"<li>%En fylld grå rektangel representerar den strukt eller klass "
+	"som har genererat grafen.</li>\n"
+	"<li>%En rektangel med svart kant symboliserar en dokumenterad strukt eller klass.</li>\n"
+	"<li>%En rektangel med grå kant symboliserar en odokumenterad strukt eller klass.</li>\n"
 	"<li>%En klass med röd kant symboliserar en strukt eller klass där "
-	"alla dess relationer inte visas. %En graf stympas om den inte får "
-	"plats inom de givna gränserna.\n"
+	"alla dess relationer inte visas. %En graf trunkeras om den inte får "
+	"plats inom de givna gränserna.</li>\n"
         "</ul>\n"
+        "<p>\n"
 	"Pilarna har följande betydelser:\n"
+        "</p>\n"
         "<ul>\n"
 	"<li>%En mörkblå pil används för att visualisera en publik arvrelation "
-	"mellan två klasser.\n"
-	"<li>%En mörkgrön pil används för en skyddad arvsrelation.\n"
-	"<li>%En mörkröd pil används för en privat arvsrelation.\n"
+	"mellan två klasser.</li>\n"
+	"<li>%En mörkgrön pil används för en skyddad arvsrelation.</li>\n"
+	"<li>%En mörkröd pil används för en privat arvsrelation.\n</li>"
 	"<li>%En sträckad lila pil används om en klass är innesluten eller "
 	"använd av en annan klass. Vid pilen står namnet på den eller de "
-	"variabler som klassen pilen pekar på kommer åt.\n"
+	"variabler som klassen pilen pekar på kommer åt.</li>\n"
 	"<li>%En sträckad gul pil symboliserar förhållandet mellan en "
 	"template-instans och template-klassen, som den instantierades från.\n"
-	"Vid pilen står instansens template-parametrar.\n"
+	"Vid pilen står instansens template-parametrar.</li>\n"
         "</ul>\n";
     }
 
@@ -1085,7 +1087,7 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
      */
     virtual QCString trNamespace(bool first_capital, bool singular)
     {
-      QCString result((first_capital ? "Namnrymd" : "namnrynd"));
+      QCString result((first_capital ? "Namnrymd" : "namnrymd"));
       if (!singular)  result+="er";
       return result;
     }
@@ -1604,6 +1606,262 @@ class TranslatorSwedish : public TranslatorAdapter_1_6_0
     {
       return "Typbegränsningar";
     }
+	
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.0 (mainly for the new search engine)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! directory relation for \a name */
+    virtual QCString trDirRelation(const char *name)
+    {
+      return QCString(name)+" Relation";
+    }
+
+    /*! Loading message shown when loading search results */
+    virtual QCString trLoading()
+    {
+      return "Laddar...";
+    }
+
+    /*! Label used for search results in the global namespace */
+    virtual QCString trGlobalNamespace()
+    {
+      return "Globalnamnrymd";
+    }
+
+    /*! Message shown while searching */
+    virtual QCString trSearching()
+    {
+      return "Söker...";
+    }
+
+    /*! Text shown when no search results are found */
+    virtual QCString trNoMatches()
+    {
+      return "Inga träffar";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.6.3 (missing items for the directory pages)
+//////////////////////////////////////////////////////////////////////////
+
+    /*! when clicking a directory dependency label, a page with a
+     *  table is shown. The heading for the first column mentions the
+     *  source file that has a relation to another file.
+     */
+    virtual QCString trFileIn(const char *name)
+    {
+      return (QCString)"Fil i "+name;
+    }
+
+    /*! when clicking a directory dependency label, a page with a
+     *  table is shown. The heading for the second column mentions the
+     *  destination file that is included.
+     */
+    virtual QCString trIncludesFileIn(const char *name)
+    {
+      return (QCString)"Inkluderar fil i "+name;
+    }
+
+    /** Compiles a date string.
+     *  @param year Year in 4 digits
+     *  @param month Month of the year: 1=January
+     *  @param day Day of the Month: 1..31
+     *  @param dayOfWeek Day of the week: 1=Monday..7=Sunday
+     *  @param hour Hour of the day: 0..23
+     *  @param minutes Minutes in the hour: 0..59
+     *  @param seconds Seconds within the minute: 0..59
+     *  @param includeTime Include time in the result string?
+     */
+    virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
+                                int hour,int minutes,int seconds,
+                                bool includeTime)
+    {
+      static const char *days[]   = { "Mån","Tis","Ons","Tor","Fre","Lör","Sön" };
+      static const char *months[] = { "Jan","Feb","Mar","Apr","Maj","Jun","Jul","Aug","Sep","Oct","Nov","Dec" };
+      QCString sdate;
+      sdate.sprintf("%s %d %s %d",days[dayOfWeek-1],day,months[month-1],year);
+      if (includeTime)
+      {
+        QCString stime;
+        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        sdate+=stime;
+      }
+      return sdate;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.7.5
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Header for the page with bibliographic citations */
+    virtual QCString trCiteReferences()
+    { return "Bibliografiska Referenser"; }
+
+    /*! Text for copyright paragraph */
+    virtual QCString trCopyright()
+    { return "Copyright"; }
+
+    /*! Header for the graph showing the directory dependencies */
+    virtual QCString trDirDepGraph(const char *name)
+    { return QCString("Katalogberoendegraf för ")+name+":"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.0
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Detail level selector shown for hierarchical indices */
+    virtual QCString trDetailLevel()
+    { return "detaljnivå"; }
+
+    /*! Section header for list of template parameters */
+    virtual QCString trTemplateParameters()
+    { return "Mall Parametrar"; }
+
+    /*! Used in dot graph when UML_LOOK is enabled and there are many fields */
+    virtual QCString trAndMore(const QCString &number)
+    { return "och "+number+" flera..."; }
+
+    /*! Used file list for a Java enum */
+    virtual QCString trEnumGeneratedFromFiles(bool single)
+    { QCString result = "Dokumentationen för denna enum var genererad från föjlande fil";
+      if (!single) result += "er";
+      result+=":";
+      return result;
+    }
+
+    /*! Header of a Java enum page (Java enums are represented as classes). */
+    virtual QCString trEnumReference(const char *name)
+    { return QCString(name)+" Enum Referens"; }
+
+    /*! Used for a section containing inherited members */
+    virtual QCString trInheritedFrom(const char *members,const char *what)
+    { return QCString(members)+" ärvd ifrån "+what; }
+
+    /*! Header of the sections with inherited members specific for the
+     *  base class(es)
+     */
+    virtual QCString trAdditionalInheritedMembers()
+    { return "Ytterliga Ärvda Medlemmar"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.2
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a tooltip for the toggle button that appears in the
+     *  navigation tree in the HTML output when GENERATE_TREEVIEW is
+     *  enabled. This tooltip explains the meaning of the button.
+     */
+    virtual QCString trPanelSynchronisationTooltip(bool enable)
+    {
+      QCString opt = enable ? "aktivera" : "inaktivera"; 
+      return "klicka för att "+opt+" panel synkronisering";
+    }
+
+    /*! Used in a method of an Objective-C class that is declared in a
+     *  a category. Note that the @1 marker is required and is replaced
+     *  by a link.
+     */
+    virtual QCString trProvidedByCategory()
+    {
+      return "Tillhandahålls av kategori @0.";
+    }
+
+    /*! Used in a method of an Objective-C category that extends a class.
+     *  Note that the @1 marker is required and is replaced by a link to
+     *  the class method.
+     */
+    virtual QCString trExtendsClass()
+    {
+      return "Utökar klass @0.";
+    }
+
+    /*! Used as the header of a list of class methods in Objective-C.
+     *  These are similar to static public member functions in C++.
+     */
+    virtual QCString trClassMethods()
+    {
+      return "Klassmetoder";
+    }
+
+    /*! Used as the header of a list of instance methods in Objective-C.
+     *  These are similar to public member functions in C++.
+     */
+    virtual QCString trInstanceMethods()
+    {
+      return "Instansmetoder";
+    }
+
+    /*! Used as the header of the member functions of an Objective-C class.
+     */
+    virtual QCString trMethodDocumentation()
+    {
+      return "Metoddokumentation";
+    }
+
+    /*! Used as the title of the design overview picture created for the
+     *  VHDL output.
+     */
+    virtual QCString trDesignOverview()
+    {
+      return "Designöversikt";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.4
+//////////////////////////////////////////////////////////////////////////
+
+    /** old style UNO IDL services: implemented interfaces */
+    virtual QCString trInterfaces()
+    { return "Exporterade Interface"; }
+
+    /** old style UNO IDL services: inherited services */
+    virtual QCString trServices()
+    { return "Inkuderade Tjänster"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroups()
+    { return "Konstant Grupper"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroupReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+=" Konstant Grupp Referens";
+      return result;
+    }
+    /** UNO IDL service page title */
+    virtual QCString trServiceReference(const char *sName)
+    {
+      QCString result=(QCString)sName;
+      result+=" Tjänstereferens";
+      return result;
+    }
+    /** UNO IDL singleton page title */
+    virtual QCString trSingletonReference(const char *sName)
+    {
+      QCString result=(QCString)sName;
+      result+=" Singleton Referens";
+      return result;
+    }
+    /** UNO IDL service page */
+    virtual QCString trServiceGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)"Dokumentationen för denna tjänst "
+                                "genererades från följande fil";
+      if (single) result+=":"; else result+="er:";
+      return result;
+    }
+    /** UNO IDL singleton page */
+    virtual QCString trSingletonGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)"Dokumentationen för denna singleton"
+                                "genererades från följande fil";
+      if (single) result+=":"; else result+="er:";
+      return result;
+    }
 
 /*---------- For internal use: ----------------------------------------*/
   protected:
